<?php
/**
 * Plugin Name: BGTFW Allow Nav Menu Link Title Attributes
 * Description: Enables the nav menu link title attributes to work properly in BoldGrid Theme Framework v1 based themes.
 * Plugin URI: https://gist.github.com/timelsass/c4e445f6fef189aa843ddf251586b2d4
 * Author: Tim Elsass
 * Author URI: tim.ph
 */

/**
 * Filters the nav menu link attributes to override the title attribute.
 *
 * In versions prior to 1.6.0 of BGTFW based themes, the title attribute is
 * automatically populated based on the title of the link.  This is not always
 * the desirable behavior, so this plugin treats the title attribute field
 * the way it was intended to work.  If you add a title attribute, then it is
 * populated, otherwise it will not be displayed.
 *
 * @link https://github.com/BoldGrid/boldgrid-theme-framework/issues/110
 * @link https://developer.wordpress.org/reference/hooks/nav_menu_link_attributes/
 */
add_filter( 'nav_menu_link_attributes', function( $atts, $item ) {
	$atts['title'] = ! empty( $item->attr_title ) ? $item->attr_title : '';
	return $atts;
}, 15, 2 );